@@ -1,9 +1,9 @@
 def ml(audio):
     import librosa
     import torch
-    from transformers import Wav2Vec2ForCTC, Wav2Vec2Tokenizer
+    from transformers import Wav2Vec2ForCTC, Wav2Vec2Processor
     #load pre-trained model and tokenizer
-    tokenizer = Wav2Vec2Tokenizer.from_pretrained("facebook/wav2vec2-base-960h")
+    tokenizer = Wav2Vec2Processor.from_pretrained("facebook/wav2vec2-base-960h")
     model = Wav2Vec2ForCTC.from_pretrained("facebook/wav2vec2-base-960h")
     #load any audio file of your choice
     speech, rate = librosa.load(audio,sr=16000)
